@@ -1,6 +1,3 @@
-import os
-from pathlib import Path
-
 from travel.cli.base import TravelCommand
 from travel.config.bag import Bag
 from travel.custom.scopes.scoped_venvs import ScopedVirtualenvs
