@@ -8,7 +8,8 @@ from travel.tools.executable import Executable
 class Python(Executable):
 
     def __init__(self, path: str = None, pre_command: str = None):
-        self.path = path or os.environ.get("TRAVEL_PYTHON_PATH", sys.executable)
+        path = path or os.environ.get("TRAVEL_PYTHON_PATH", sys.executable)
+        self.path = f'"{path}"'
         super().__init__(self.path, pre_command=pre_command)
         # TODO version from Popen
 
